@@ -25,12 +25,15 @@ Design:
 
 import sys
 import os
+import os
 import threading
 import time
 import logging
 import base64
+import base64
 from http.server import HTTPServer, BaseHTTPRequestHandler
 from typing import Optional, Any, Tuple
+from typing import Optional, Any, Tuple
 from prometheus_client import generate_latest, CONTENT_TYPE_LATEST
 
 # Configure logger
@@ -56,6 +59,11 @@ class MetricsHTTPHandler(BaseHTTPRequestHandler):
     - GET /health -> Return 200 OK (no auth required)
     - All other requests -> 404
     
+    Security:
+    - Basic authentication support (if credentials configured)
+    - Localhost-only default binding
+    - Read-only endpoints
+    
     Security:
     - Basic authentication support (if credentials configured)
     - Localhost-only default binding
@@ -63,10 +71,10 @@ class MetricsHTTPHandler(BaseHTTPRequestHandler):
     """
     
     # Class variables to hold config
-    registry = None
-    auth_required = False
-    auth_username = None
-    auth_password = None
+    registry: Optional[Any] = None
+    auth_required: bool = False
+    auth_username: Optional[str] = None
+    auth_password: Optional[str] = None
     
     def log_message(self, format, *args):
         """Override to use our logger instead of stderr"""
@@ -112,16 +120,61 @@ class MetricsHTTPHandler(BaseHTTPRequestHandler):
         except Exception as e:
             _http_logger.error(f"Error sending 401: {e}")
     
+    def _check_auth(self) -> bool:
+        """
+        Check HTTP Basic Authentication credentials.
+        
+        Returns:
+            True if auth passes or not required, False otherwise
+        """
+        if not self.auth_required:
+            return True
+        
+        auth_header = self.headers.get('Authorization', '')
+        if not auth_header.startswith('Basic '):
+            return False
+        
+        try:
+            # Decode base64 credentials
+            encoded_creds = auth_header[6:]  # Remove 'Basic ' prefix
+            decoded = base64.b64decode(encoded_creds).decode('utf-8')
+            username, password = decoded.split(':', 1)
+            
+            # Check credentials
+            return (username == self.auth_username and 
+                    password == self.auth_password)
+        except Exception as e:
+            _http_logger.warning(f"Auth check failed: {e}")
+            return False
+    
+    def _send_auth_required(self):
+        """Send 401 Unauthorized response"""
+        try:
+            message = b"401 Unauthorized\n\nBasic authentication required.\n"
+            self.send_response(401)
+            self.send_header('WWW-Authenticate', 'Basic realm="CrashLens Metrics"')
+            self.send_header('Content-Type', 'text/plain')
+            self.send_header('Content-Length', str(len(message)))
+            self.end_headers()
+            self.wfile.write(message)
+        except Exception as e:
+            _http_logger.error(f"Error sending 401: {e}")
+    
     def do_GET(self):
         """Handle GET requests"""
         try:
             if self.path == '/metrics':
                 # Auth required for metrics endpoint
+                if not self._check_auth():
+                    self._send_auth_required()
+                    return
+                # Auth required for metrics endpoint
                 if not self._check_auth():
                     self._send_auth_required()
                     return
                 self._handle_metrics()
             elif self.path == '/health':
+                # No auth for health check
                 # No auth for health check
                 self._handle_health()
             else:
@@ -203,12 +256,20 @@ class MetricsHTTPServer:
     - Optional Basic authentication
     - TTY/interactivity checks
     
+    Security Model:
+    - Localhost (127.0.0.1) binding = no auth required
+    - Non-localhost binding = auth required (or explicit override)
+    - TTY check before exposing on non-localhost
+    - Optional Basic authentication
+    - TTY/interactivity checks
+    
     Security Model:
     - Localhost (127.0.0.1) binding = no auth required
     - Non-localhost binding = auth required (or explicit override)
     - TTY check before exposing on non-localhost
     
     Example:
+        >>> # Localhost - no auth
         >>> # Localhost - no auth
         >>> server = MetricsHTTPServer(metrics, '127.0.0.1', 9090)
         >>> url = server.start()
@@ -219,6 +280,13 @@ class MetricsHTTPServer:
         ...     auth_username='admin', auth_password='secret123'
         ... )
         >>> url = server.start()
+        
+        >>> # Non-localhost - auth required
+        >>> server = MetricsHTTPServer(
+        ...     metrics, '0.0.0.0', 9090,
+        ...     auth_username='admin', auth_password='secret123'
+        ... )
+        >>> url = server.start()
     """
     
     def __init__(
@@ -241,6 +309,12 @@ class MetricsHTTPServer:
             auth_password: Password for Basic auth (required for non-localhost)
             skip_tty_check: Skip TTY check (for automated environments)
         
+        Raises:
+            ValueError: If non-localhost binding without auth credentials
+            auth_username: Username for Basic auth (required for non-localhost)
+            auth_password: Password for Basic auth (required for non-localhost)
+            skip_tty_check: Skip TTY check (for automated environments)
+        
         Raises:
             ValueError: If non-localhost binding without auth credentials
         """
@@ -256,6 +330,21 @@ class MetricsHTTPServer:
         # Determine if auth is required
         is_localhost = host in ('127.0.0.1', 'localhost', '::1')
         
+        if not is_localhost:
+            # Non-localhost requires auth
+            if not auth_username or not auth_password:
+                raise ValueError(
+                    f"Authentication required for non-localhost binding ({host}).\n"
+                    "Provide auth_username and auth_password, or bind to 127.0.0.1.\n"
+                    "See docs/HTTP_SERVER_SECURITY.md for details."
+                )
+        
+        # Set registry and auth config for handler
+        self.skip_tty_check = skip_tty_check
+        
+        # Determine if auth is required
+        is_localhost = host in ('127.0.0.1', 'localhost', '::1')
+        
         if not is_localhost:
             # Non-localhost requires auth
             if not auth_username or not auth_password:
@@ -279,6 +368,49 @@ class MetricsHTTPServer:
         else:
             MetricsHTTPHandler.auth_required = False
     
+    def _check_tty_approval(self) -> bool:
+        """
+        Check if running in interactive TTY and get user approval for non-localhost.
+        
+        Returns:
+            True if approved or check skipped, False otherwise
+        """
+        if self.skip_tty_check:
+            return True
+        
+        # Only check for non-localhost bindings
+        is_localhost = self.host in ('127.0.0.1', 'localhost', '::1')
+        if is_localhost:
+            return True
+        
+        # Check if stdin is a TTY
+        if not sys.stdin.isatty():
+            _http_logger.error(
+                f"Cannot bind to {self.host} in non-interactive environment. "
+                "Use --skip-tty-check flag if intentional."
+            )
+            return False
+        
+        # Interactive approval
+        print(f"\n⚠️  WARNING: You are about to expose metrics on {self.host}:{self.port}", file=sys.stderr)
+        print("   This will be accessible from other machines on the network.", file=sys.stderr)
+        print("   Authentication is enabled. Credentials required for access.", file=sys.stderr)
+        
+        try:
+            response = input("\nProceed? (yes/no): ").strip().lower()
+            return response in ('yes', 'y')
+        except (EOFError, KeyboardInterrupt):
+            print("\nAborted.", file=sys.stderr)
+            return False
+        
+        # Configure authentication
+        if auth_username and auth_password:
+            MetricsHTTPHandler.auth_required = True
+            MetricsHTTPHandler.auth_username = auth_username
+            MetricsHTTPHandler.auth_password = auth_password
+        else:
+            MetricsHTTPHandler.auth_required = False
+    
     def _check_tty_approval(self) -> bool:
         """
         Check if running in interactive TTY and get user approval for non-localhost.
@@ -323,6 +455,7 @@ class MetricsHTTPServer:
         
         Raises:
             RuntimeError: If server cannot bind to any port or TTY check fails
+            RuntimeError: If server cannot bind to any port or TTY check fails
         
         Process:
         1. Check TTY approval for non-localhost bindings
@@ -332,6 +465,13 @@ class MetricsHTTPServer:
         5. Start server in daemon thread
         6. Print security audit banner to stderr
         7. Return server URL
+        1. Check TTY approval for non-localhost bindings
+        2. Check if port is available
+        3. If not, try port+1, port+2
+        4. If all fail, raise RuntimeError
+        5. Start server in daemon thread
+        6. Print security audit banner to stderr
+        7. Return server URL
         """
         # Check TTY approval first
         if not self._check_tty_approval():
@@ -341,6 +481,14 @@ class MetricsHTTPServer:
                 "Use --skip-tty-check flag to bypass (NOT recommended for production)."
             )
         
+        # Check TTY approval first
+        if not self._check_tty_approval():
+            raise RuntimeError(
+                f"TTY approval required for non-localhost binding to {self.host}. "
+                "User declined or non-interactive environment detected. "
+                "Use --skip-tty-check flag to bypass (NOT recommended for production)."
+            )
+        
         # Import here to avoid circular dependency
         from crashlens.observability.server import check_port_available
         
@@ -394,6 +542,11 @@ class MetricsHTTPServer:
                     # Handle one request with timeout
                     self.httpd.timeout = 0.5  # Check running flag every 500ms
                     self.httpd.handle_request()
+            if self.httpd is not None:
+                while self.running:
+                    # Handle one request with timeout
+                    self.httpd.timeout = 0.5  # Check running flag every 500ms
+                    self.httpd.handle_request()
         except Exception as e:
             if self.running:  # Only log if not deliberately stopped
                 _http_logger.error(f"HTTP server error: {e}")
@@ -438,12 +591,18 @@ class MetricsHTTPServer:
         auth_status = "✓ Basic auth enabled" if MetricsHTTPHandler.auth_required else "⚠️  No authentication"
         binding_warning = "" if is_localhost else "\n   ⚠️  WARNING: Exposed on network - ensure firewall is configured"
         
+        is_localhost = self.host in ('127.0.0.1', 'localhost', '::1')
+        auth_status = "✓ Basic auth enabled" if MetricsHTTPHandler.auth_required else "⚠️  No authentication"
+        binding_warning = "" if is_localhost else "\n   ⚠️  WARNING: Exposed on network - ensure firewall is configured"
+        
         banner = f"""
 ⚠️  WARNING: Metrics HTTP server enabled
    Endpoint: {server_url}/metrics
    Health check: {server_url}/health
    Authentication: {auth_status}
    Binding: {self.host}:{self.actual_port} {'(localhost-only)' if is_localhost else '(network-accessible)'}{binding_warning}
+   Authentication: {auth_status}
+   Binding: {self.host}:{self.actual_port} {'(localhost-only)' if is_localhost else '(network-accessible)'}{binding_warning}
    To disable: Remove --metrics-http flag or unset CRASHLENS_ALLOW_HTTP_METRICS
 """
         # Print to stderr so it doesn't interfere with stdout
